@@ -2,9 +2,9 @@
 /**
  * Scatter plot implementation for the Horde_Graph package.
  *
- * $Horde: framework/Graph/Graph/Plot/scatter.php,v 1.3.12.2 2005/04/21 11:26:41 selsky Exp $
+ * $Horde: framework/Graph/Graph/Plot/scatter.php,v 1.3.12.4 2006/01/01 21:28:18 jan Exp $
  *
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -30,7 +30,7 @@ class Horde_Graph_Plot_scatter {
         }
     }
 
-    function draw()
+    function draw($minY = false)
     {
         $data = $this->_graph->_data['y'][$this->_dataset];
 
@@ -38,9 +38,11 @@ class Horde_Graph_Plot_scatter {
         $verts = array();
         for ($i = 0; $i < $count; $i++) {
             $x = $i;
-            $y = $data[$i];
-            $this->_graph->translate($x, $y);
-            $this->_graph->img->brush($x, $y, $this->_color, $this->_shape);
+            if ($minY === false || $data[$i] >= $minY) {
+                $y = $data[$i];
+                $this->_graph->translate($x, $y);
+                $this->_graph->img->brush($x, $y, $this->_color, $this->_shape);
+            }
         }
     }
 
