@@ -6,9 +6,9 @@ require_once 'Horde/Util.php';
  * This class defines the Horde_Image:: API, and also provides some
  * utility functions, such as generating highlights of a color.
  *
- * $Horde: framework/Image/Image.php,v 1.39.10.10 2005/07/03 04:39:57 selsky Exp $
+ * $Horde: framework/Image/Image.php,v 1.39.10.13 2006/01/01 21:28:22 jan Exp $
  *
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -471,10 +471,12 @@ class Horde_Image {
         }
         $class = 'Horde_Image_' . $driver;
         if (class_exists($class)) {
-            return $ret = &new $class($params);
+            $image = &new $class($params);
         } else {
-            return PEAR::raiseError('Class definition of ' . $class . ' not found.');
+            $image = PEAR::raiseError('Class definition of ' . $class . ' not found.');
         }
+
+        return $image;
     }
 
     /**
