@@ -2,9 +2,9 @@
 /**
  * Horde_Mobile_Renderer:: output module for WML (Wireless Markup Language).
  *
- * $Horde: framework/Mobile/Mobile/Renderer/wml.php,v 1.32.10.4 2005/09/30 02:54:54 selsky Exp $
+ * $Horde: framework/Mobile/Mobile/Renderer/wml.php,v 1.32.10.7 2006/02/24 20:40:38 chuck Exp $
  *
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -49,9 +49,6 @@ class Horde_Mobile_Renderer_wml extends Horde_Mobile_Renderer {
             header('Content-Type: text/vnd.wap.wml; charset=utf-8');
         }
 
-        // Tricks to foil caching.
-        header('Content-location: ' . md5(date('U')));
-
         echo "<?xml version=\"1.0\"?>\n";
         if ($this->hasQuirk('ow_gui_1.3')) {
             echo '<!DOCTYPE wml PUBLIC "-//PHONE.COM//DTD WML 1.3//EN" "http://www.openwave.com/dtd/wml13.dtd">';
@@ -168,6 +165,15 @@ class Horde_Mobile_Renderer_wml extends Horde_Mobile_Renderer {
         }
     }
 
+    function _renderImage(&$image)
+    {
+        $attributes = '';
+        foreach ($image->_attributes as $attribute => $value) {
+            $attributes .= sprintf(' %s="%s"', $attribute, $value);
+        }
+        printf('<img src="%s.wbmp"%s/>', $image->_src, $attributes);
+    }
+
     function _renderInput(&$input)
     {
         $type = ' type="' . $input->get('type') . '"';
