@@ -3,12 +3,14 @@
  * SessionHandler:: implementation for MySQL (native).
  *
  * Required parameters:<pre>
- *   'hostspec'  The hostname of the database server.
- *   'protocol'  The communication protocol ('tcp', 'unix', etc.).
- *   'username'  The username with which to connect to the database.
- *   'password'  The password associated with 'username'.
- *   'database'  The name of the database.
- *   'table'     The name of the sessiondata table in 'database'.</pre>
+ *   'hostspec'   - The hostname of the database server.
+ *   'protocol'   - The communication protocol ('tcp', 'unix', etc.).
+ *   'username'   - The username with which to connect to the database.
+ *   'password'   - The password associated with 'username'.
+ *   'database'   - The name of the database.
+ *   'table'      - The name of the sessiondata table in 'database'.
+ *   'rowlocking' - Whether to use row-level locking and transactions (InnoDB)
+ *                  or table-level locking (MyISAM).</pre>
  *
  * Required for some configurations:<pre>
  *   'port'  The port on which to connect to the database.</pre>
@@ -19,15 +21,17 @@
  * The table structure for the SessionHandler can be found in
  * horde/scripts/sql/horde_sessionhandler.sql.
  *
- * $Horde: framework/SessionHandler/SessionHandler/mysql.php,v 1.16.12.7.2.1 2005/10/31 20:23:57 jan Exp $
+ * $Horde: framework/SessionHandler/SessionHandler/mysql.php,v 1.16.12.14 2006/03/29 19:06:46 jan Exp $
  *
- * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2006 Mike Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2006 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Mike Cochrame <mike@graftonhall.co.nz>
+ * @author  Jan Schneider <jan@horde.org>
  * @since   Horde 3.0
  * @package Horde_SessionHandler
  */
@@ -79,19 +83,23 @@ class SessionHandler_mysql extends SessionHandler {
         /* Session timeout, don't rely on garbage collection. */
         $timeout = time() - ini_get('session.gc_maxlifetime');
 
-        /* Start a transaction. */
-        $result = @mysql_query('SET AUTOCOMMIT=0', $this->_db);
-        $result = @mysql_query('BEGIN', $this->_db);
-        if (!$result) {
-            return '';
-        }
-
         $query = sprintf('SELECT session_data FROM %s WHERE session_id = %s' .
                          ' AND session_lastmodified > %s',
                          $this->_params['table'],
                          $this->_quote($id),
                          $timeout);
 
+        if (!empty($this->_params['rowlocking'])) {
+            /* Start a transaction. */
+            $result = @mysql_query('START TRANSACTION', $this->_db);
+            $query .= ' FOR UPDATE';
+        } else {
+            $result = @mysql_query('LOCK TABLES ' . $this->_params['table'] . ' WRITE', $this->_db);
+        }
+        if (!$result) {
+            return '';
+        }
+
         /* Log the query at a DEBUG log level. */
         Horde::logMessage(sprintf('SQL Query by SessionHandler_mysql::read(): query = "%s"', $query),
                           __FILE__, __LINE__, PEAR_LOG_DEBUG);
@@ -128,15 +136,16 @@ class SessionHandler_mysql extends SessionHandler {
                          time());
 
         $result = @mysql_query($query, $this->_db);
+        if (empty($this->_params['rowlocking'])) {
+            @mysql_query('UNLOCK TABLES ' . $this->_params['table'], $this->_db);
+        }
         if (!$result) {
-            $result = @mysql_query('ROLLBACK', $this->_db);
-            $result = @mysql_query('SET AUTOCOMMIT=1', $this->_db);
+            @mysql_query('ROLLBACK', $this->_db);
             Horde::logMessage('Error writing session data', __FILE__, __LINE__, PEAR_LOG_ERR);
             return false;
         }
 
-        $result = @mysql_query('COMMIT', $this->_db);
-        $result = @mysql_query('SET AUTOCOMMIT=1', $this->_db);
+        @mysql_query('COMMIT', $this->_db);
 
         return true;
     }
@@ -164,15 +173,16 @@ class SessionHandler_mysql extends SessionHandler {
 
         /* Execute the query. */
         $result = @mysql_query($query, $this->_db);
+        if (empty($this->_params['rowlocking'])) {
+            @mysql_query('UNLOCK TABLES ' . $this->_params['table'], $this->_db);
+        }
         if (!$result) {
-            $result = @mysql_query('ROLLBACK', $this->_db);
-            $result = @mysql_query('SET AUTOCOMMIT=1', $this->_db);
+            @mysql_query('ROLLBACK', $this->_db);
             Horde::logMessage('Failed to delete session (id = ' . $id . ')', __FILE__, __LINE__, PEAR_LOG_ERR);
             return false;
         }
 
-        $result = @mysql_query('COMMIT', $this->_db);
-        $result = @mysql_query('SET AUTOCOMMIT=1', $this->_db);
+        @mysql_query('COMMIT', $this->_db);
 
         return true;
     }
@@ -264,7 +274,7 @@ class SessionHandler_mysql extends SessionHandler {
 
         case 'string':
         default:
-            return "'" . @mysql_real_escape_string($value) . "'";
+            return "'" . @mysql_real_escape_string($value, $this->_db) . "'";
         }
     }
 
