@@ -3,11 +3,12 @@
  * The Horde_UI_VarRenderer:: class provides base functionality for
  * other Horde UI elements.
  *
- * $Horde: framework/UI/UI/VarRenderer.php,v 1.12.10.5.2.1 2005/12/05 16:32:03 chuck Exp $
+ * $Horde: framework/UI/UI/VarRenderer.php,v 1.12.10.10 2006/06/20 09:08:45 jan Exp $
  *
- * Copyright 2003-2005 Jason M. Felice <jfelice@cronosys.com>
+ * Copyright 2003-2006 Jason M. Felice <jfelice@cronosys.com>
  *
- * See the enclosed file LICENSE for license information (LGPL).
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @since   Horde_UI 0.0.1
  * @package Horde_UI
@@ -71,10 +72,12 @@ class Horde_UI_VarRenderer {
 
         $class = 'Horde_UI_VarRenderer_' . $driver;
         if (class_exists($class)) {
-            return $ret = &new $class($params);
+            $vr = &new $class($params);
         } else {
-            return PEAR::raiseError('Class definition of ' . $class . ' not found.');
+            $vr = PEAR::raiseError('Class definition of ' . $class . ' not found.');
         }
+
+        return $vr;
     }
 
     /**
