@@ -5,16 +5,15 @@ require_once dirname(__FILE__) . '/../VFS.php';
 /**
  * A wrapper for the VFS class to return objects, instead of arrays.
  *
- * $Horde: framework/VFS/VFS/Object.php,v 1.12.10.6 2005/07/03 04:52:42 selsky Exp $
+ * $Horde: framework/VFS/VFS/Object.php,v 1.12.10.11 2006/05/31 04:50:02 slusarz Exp $
  *
- * Copyright 2002-2005 Jon Wood <jon@jellybob.co.uk>
+ * Copyright 2002-2006 Jon Wood <jon@jellybob.co.uk>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jon Wood <jon@jellybob.co.uk>
  * @package VFS
- * @since   Horde 2.2
  */
 class VFS_Object {
 
@@ -72,7 +71,8 @@ class VFS_Object {
     function &factory($driver, $params = array())
     {
         $vfs = &VFS::factory($driver, $params = array());
-        return $ret = &new VFS_Object($vfs);
+        $vfsobject = &new VFS_Object($vfs);
+        return $vfsobject;
     }
 
     /**
@@ -98,7 +98,8 @@ class VFS_Object {
     function &singleton($driver, $params = array())
     {
         $vfs = &VFS::singleton($driver, $params = array());
-        return $ret = &new VFS_Object($vfs);
+        $vfsobject = &new VFS_Object($vfs);
+        return $vfsobject;
     }
 
     /**
