@@ -1,9 +1,9 @@
 <?php
 /**
- * $Horde: horde/services/prefs.php,v 1.19.2.4.2.1 2005/12/11 18:05:42 chuck Exp $
+ * $Horde: horde/services/prefs.php,v 1.19.2.10 2006/02/07 23:50:00 jan Exp $
  *
- * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2005 Jon Parise <jon@horde.org>
+ * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -22,23 +22,22 @@ $appbase = $registry->get('fileroot', $app);
 /* See if we have a preferences group set. */
 $group = Util::getFormData('group');
 
-/* Load $app's base environment. */
+/* Load $app's base environment, but don't request that the app perform
+ * authentication beyond Horde's. */
+$authentication = 'none';
 require_once $appbase . '/lib/base.php';
 
 /* Set title. */
 $title = sprintf(_("Options for %s"), $registry->get('name'));
 
-if ($group == 'identities') {
+/* Special case where we need the Identity object in Horde's prefs.php. */
+if ($group == 'identities' && $app == 'horde') {
     require_once 'Horde/Identity.php';
     $identity = &Identity::singleton($app == 'horde' ? null : array($app, $app));
-    if ($app != 'horde') {
-        require HORDE_BASE . '/config/prefs.php';
-        $horde_members = $prefGroups['identities']['members'];
-        unset($prefGroups);
-    }
 }
 
 /* Load $app's preferences, if any. */
+$prefGroups = array();
 if (file_exists($appbase . '/config/prefs.php')) {
     require $appbase . '/config/prefs.php';
 }
@@ -48,7 +47,29 @@ if (file_exists($appbase . '/lib/prefs.php')) {
     require_once $appbase . '/lib/prefs.php';
 }
 
+/* If there's only one prefGroup, just show it. */
+if (empty($group) && count($prefGroups) == 1) {
+    $group = array_keys($prefGroups);
+    $group = array_pop($group);
+}
+
 if ($group == 'identities') {
+    require_once 'Horde/Identity.php';
+    $identity = &Identity::singleton($app == 'horde' ? null : array($app, $app));
+    if ($app != 'horde') {
+        if (Util::nonInputVar('prefGroups')) {
+            $keepPrefGroups = $prefGroups;
+            unset($prefGroups);
+        }
+        require HORDE_BASE . '/config/prefs.php';
+        $horde_members = $prefGroups['identities']['members'];
+        if (Util::nonInputVar('keepPrefGroups')) {
+            $prefGroups = $keepPrefGroups;
+        } else {
+            unset($prefGroups);
+        }
+    }
+
     if (isset($horde_members)) {
         $prefGroups['identities']['members'] = array_merge($horde_members, $prefGroups['identities']['members']);
     }
@@ -89,6 +110,13 @@ if ($group == 'identities') {
         unset($_prefs['default_identity']['enum'][$id]);
         $notification->push(sprintf(_("The identity \"%s\" has been deleted."), $deleted_identity[0]['id']), 'horde.success');
         break;
+
+    case 'change_default_identity':
+        $default_identity = $identity->setDefault(Util::getFormData('id'));
+        $identity->save();
+        $notification->push(_("Your default identity has been changed."),
+                            'horde.success');
+        break;
     }
 } elseif (Prefs_UI::handleForm($group, $prefs)) {
     require $appbase . '/config/prefs.php';
